@@ -5,7 +5,13 @@ use warnings;
 use Template 2.14;
 use Getopt::Long;
 
-our $VERSION = '0.23';
+=head1 VERSION
+
+Version 0.25
+
+=cut
+ 
+our $VERSION = '0.25';
 
 use Jemplate::Parser;
 
@@ -77,7 +83,7 @@ sub main {
     my ($runtime, $compile, $list) = @$jemplate_options{qw/runtime compile list/};
 
     if ($runtime) {
-        runtime_source_code(@$jemplate_options{qw/runtime ajax json xhr xxx compact/});
+        print runtime_source_code(@$jemplate_options{qw/runtime ajax json xhr xxx compact/});
         return unless $compile;
     }
 
@@ -232,7 +238,7 @@ sub make_file_list {
 
     foreach my $arg (@args) {
         unless (-e $arg) { next; } # file exists
-        unless (-s $arg) { next; } # file size > 0
+        unless (-s $arg or -d $arg) { next; } # file size > 0 or directory (for Win platform)
 
         if (-d $arg) {
             foreach my $full ( recurse_dir($arg) ) {
@@ -262,6 +268,8 @@ sub runtime_source_code {
     require Jemplate::Runtime;
     require Jemplate::Runtime::Compact;
 
+    unshift @_, "standard" unless @_;
+
     my ($runtime, $ajax, $json, $xhr, $xxx, $compact) = map { defined $_ ? lc $_ : "" } @_[0 .. 5];
 
     my $Jemplate_Runtime = $compact ? "Jemplate::Runtime::Compact" : "Jemplate::Runtime";
@@ -311,7 +319,7 @@ sub runtime_source_code {
 
     push @runtime, $Jemplate_Runtime->xxx if $xxx;
 
-    print join ";", @runtime;
+    return join ";", @runtime;
 }
 
 #-------------------------------------------------------------------------------
@@ -383,7 +391,7 @@ sub _preamble {
    Template Toolkit. Any changes made to this file will be lost the next
    time the templates are compiled.
 
-   Copyright 2006 - Ingy döt Net - All rights reserved.
+   Copyright 2006-2008 - Ingy döt Net - All rights reserved.
 */
 
 if (typeof(Jemplate) == 'undefined')
@@ -420,6 +428,10 @@ or, with jQuery.js:
         Jemplate.process('my-template.html', data, '#some-div');
     });
 
+From the commandline:
+
+    jemplate --runtime --compile path/to/jemplate/directory/ > jemplate.js
+
 =head1 DESCRIPTION
 
 Jemplate is a templating framework for JavaScript that is built over
@@ -585,12 +597,13 @@ Jemplate now supports almost all the TT directives, including:
   * [% LAST %]
   * [% CLEAR %]
   * [%# this is a comment %]
+  * [% MACRO name(param1, param2) BLOCK %] ... [% END %]  
 
 ALL of the string virtual functions are supported.
 
 ALL of the array virtual functions are supported:
 
-ALL of the hash virtual functions are supported (except for import):
+ALL of the hash virtual functions are supported:
 
 MANY of the standard filters are implemented.
 
@@ -611,8 +624,8 @@ All tests run 100% successful in the above browsers.
 
 =head1 DEVELOPMENT
 
-The bleeding edge code is available via Subversion at
-http://svn.jemplate.net/repo/trunk/
+The bleeding edge code is available via Git at
+git://github.com/ingydotnet/jemplate.git
 
 You can run the runtime tests directly from
 http://svn.jemplate.net/repo/trunk/tests/run/index.html or from the
@@ -655,6 +668,8 @@ David A. Coffey <dacoffey@cogsmith.com>
 
 Robert Krimen <robertkrimen@gmail.com>
 
+Nickolay Platonov <nickolay8@gmail.com>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2006-2008. Ingy döt Net.
